"""
A Quasar is a radio emitting active galactic nucleus (i.e. an actively feeding supermassive black hole).
Radio Astronomy for the win!!!!
"""
import argparse
import logging
import os
import sys

from vela.emulators import CasaEmulator

"""
The Vela system allows for testing Workspaces workflows without submitting to CASA on the cluster.
"""

logger = logging.getLogger("vela")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


def parser() -> argparse.ArgumentParser:
    arg_parser = argparse.ArgumentParser(
        description="Workspaces VELA processing launcher",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    arg_parser.add_argument(
        "-f",
        "--files",
        nargs=2,
        action="store",
        required=True,
    )
    arg_parser.add_argument(
        "--standard-cal",
        action="store_true",
        required=False,
        help="run the standard calibration pipeline",
    )
    arg_parser.add_argument(
        "--standard-img",
        action="store_true",
        required=False,
        help="run the standard imaging pipeline",
    )
    arg_parser.add_argument(
        "--restore",
        action="store_true",
        required=False,
        help="run the restore measurement set VELA pipeline",
    )
    arg_parser.add_argument(
        "--integrated",
        action="store_true",
        required=False,
        help="run an integrated calibration-imaging pipeline",
    )
    return arg_parser


def main():
    args = parser().parse_args()

    metadata = args.files[0]
    ppr = args.files[1]

    path = os.getcwd()
    if args.standard_cal is not None:
        product_type = "standard_cal"
    elif args.standard_img is not None:
        product_type = "standard_img"
    elif args.restore is not None:
        product_type = "restore"
    elif args.integrated is not None:
        product_type = "integrated"
    else:
        logger.info("ARGUMENT ERROR: no valid argument was provided.")

    CasaEmulator(metadata, ppr, product_type).run()
    os.chdir(path)
